(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 12.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     37386,       1031]
NotebookOptionsPosition[     33439,        958]
NotebookOutlinePosition[     33852,        974]
CellTagsIndexPosition[     33809,        971]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 "The Decay V \[Rule] ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Pi]", "0"], 
    SuperscriptBox["l", "+"], 
    SuperscriptBox["l", "-"]}], TraditionalForm]],
  FormatType->"TraditionalForm",ExpressionUUID->
  "7ef08b91-2cfc-4ab3-b66b-f36bbdd1e5e6"]
}], "Title",
 CellChangeTimes->{{3.828533466382832*^9, 3.828533473980831*^9}, {
  3.828533506505295*^9, 
  3.828533522815836*^9}},ExpressionUUID->"0e5026cd-4cfe-4c5b-a278-\
e9bc6f147cbe"],

Cell[BoxData[
 RowBox[{"(*", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{
     "We", " ", "want", " ", "to", " ", "confirm", " ", "the", " ", 
      "unitarity", " ", "relation", " ", "obtained", " ", "in"}], " ", "<", 
     RowBox[{"https", ":"}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"arxiv", ".", "org"}], "/", "pdf"}], "/", 
      RowBox[{"1206.3098", ".", "pdf"}]}], ">"}]}], ";", " ", 
   RowBox[{
   "see", " ", "also", " ", "the", " ", "corresponding", " ", "handwritten", 
    " ", 
    RowBox[{"notes", "."}]}]}], " ", "*)"}]], "Input",
 CellChangeTimes->{{3.828533531273322*^9, 
  3.828533563419449*^9}},ExpressionUUID->"6142dc02-8c6e-475f-895b-\
be5ca395aa19"],

Cell[CellGroupData[{

Cell["Kinematics", "Section",
 CellChangeTimes->{{3.828533566469079*^9, 3.8285335677053432`*^9}, 
   3.828534393723267*^9},ExpressionUUID->"71485b68-cf25-4dbd-8ef7-\
d877f47b1ca1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"Useful", " ", "functions", " ", "and", " ", 
    RowBox[{"variables", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"\[Sigma]", "=", 
     SqrtBox[
      RowBox[{"1", "-", 
       FractionBox[
        RowBox[{"4", 
         SuperscriptBox["M\[Pi]", "2"]}], "s"]}]]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"\[Lambda]", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"], "+", 
      SuperscriptBox["z", "2"], "-", 
      RowBox[{"2", "x", " ", "y"}], "-", 
      RowBox[{"2", "x", " ", "z"}], "-", 
      RowBox[{"2", "y", " ", "z"}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.827903905253169*^9, 3.827903929561741*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"c9bc42c9-dcbb-4dba-9610-23afd3de30b9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energies", " ", "and", " ", "momenta", " ", "of", " ", "the", " ", 
     "initial"}], "-", 
    RowBox[{
    "state", " ", "vector", " ", "meson", " ", "V", " ", "and", " ", "the", 
     " ", "final", " ", "state", " ", 
     RowBox[{
      SuperscriptBox["\[Pi]", "0"], "."}]}]}], " ", "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["MV", "2"]}]], "-", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pInitial", "=", 
     FractionBox[
      SqrtBox[
       RowBox[{"\[Lambda]", "[", 
        RowBox[{"s", ",", 
         SuperscriptBox["MV", "2"], ",", 
         SuperscriptBox["M\[Pi]", "2"]}], "]"}]], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["pInitial", "2"], "+", 
       SuperscriptBox["MV", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["pInitial", "2"], "+", 
       SuperscriptBox["M\[Pi]", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E1Initial", "=", 
     FractionBox[
      RowBox[{
       SuperscriptBox["MV", "2"], "+", "s", "-", 
       SuperscriptBox["M\[Pi]", "2"]}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"E2Initial", "=", 
     FractionBox[
      RowBox[{
       SuperscriptBox["MV", "2"], "-", "s", "-", 
       SuperscriptBox["M\[Pi]", "2"]}], 
      RowBox[{"2", 
       SqrtBox["s"]}]]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8285343991885233`*^9, 3.828534500211405*^9}, {
  3.828535017787689*^9, 3.828535176758636*^9}, {3.828540430123554*^9, 
  3.828540433100368*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"d2085999-7b24-4df7-b8cc-a47083e07d00"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        SqrtBox[
         RowBox[{
          SuperscriptBox["M\[Pi]", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["M\[Pi]", "2"], " ", "s"}], "+", 
          SuperscriptBox["MV", "4"], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["M\[Pi]", "2"], " ", 
           SuperscriptBox["MV", "2"]}], "-", 
          RowBox[{"2", " ", 
           SuperscriptBox["MV", "2"], " ", "s"}], "+", 
          SuperscriptBox["s", "2"]}]], 
        RowBox[{"2", " ", 
         SqrtBox["s"]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       SqrtBox[
        RowBox[{
         SuperscriptBox["M\[Pi]", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["M\[Pi]", "2"], " ", "s"}], "+", 
         SuperscriptBox["MV", "4"], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["M\[Pi]", "2"], " ", 
          SuperscriptBox["MV", "2"]}], "-", 
         RowBox[{"2", " ", 
          SuperscriptBox["MV", "2"], " ", "s"}], "+", 
         SuperscriptBox["s", "2"]}]], 
       RowBox[{"2", " ", 
        SqrtBox["s"]}]]}], "}"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.8285350667458363`*^9, 3.828535082437093*^9}, 
   3.828535149581335*^9, 3.828584649095594*^9},
 CellLabel->"Out[3]=",ExpressionUUID->"aab41839-9eec-409f-a445-aa8f7de0bb79"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", 
         SuperscriptBox["M\[Pi]", "2"]}], "+", 
        SuperscriptBox["MV", "2"], "+", "s"}], ")"}], "2"], "s"]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.8285350667458363`*^9, 3.828535082437093*^9}, 
   3.828535149581335*^9, 3.828584649110395*^9},
 CellLabel->"Out[5]=",ExpressionUUID->"b52e2c04-1130-43ab-b69f-2e0282f8eeeb"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   SqrtBox[
    FractionBox[
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "-", 
        SuperscriptBox["MV", "2"], "+", "s"}], ")"}], "2"], "s"]]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.8285350667458363`*^9, 3.828535082437093*^9}, 
   3.828535149581335*^9, 3.8285846491148033`*^9},
 CellLabel->"Out[6]=",ExpressionUUID->"24e4acf7-a999-471c-8911-eee39d647b22"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energies", " ", "and", " ", "momenta", " ", "of", " ", "the", " ", 
     "intermediate"}], "-", 
    RowBox[{"state", " ", 
     RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]], "+", 
       SqrtBox[
        RowBox[{
         SuperscriptBox["p", "2"], "+", 
         SuperscriptBox["M\[Pi]", "2"]}]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pIntermediate", "=", 
     RowBox[{
      FractionBox[
       SqrtBox["s"], "2"], "\[Sigma]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      RowBox[{
       SuperscriptBox["pIntermediate", "2"], "+", 
       SuperscriptBox["M\[Pi]", "2"]}]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EIntermediate", "=", 
     FractionBox[
      SqrtBox["s"], "2"]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8285343991885233`*^9, 3.828534500211405*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"0b8e30ee-a80a-4b5c-89d3-f3cab6dd19da"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       RowBox[{"-", 
        FractionBox["1", "2"]}], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}]}]]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{
       FractionBox["1", "2"], " ", 
       SqrtBox[
        RowBox[{"s", "-", 
         RowBox[{"4", " ", 
          SuperscriptBox["M\[Pi]", "2"]}]}]]}]}], "}"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828534443170586*^9, {3.8285344926713743`*^9, 3.828534500706045*^9}, 
   3.8285349939707336`*^9, 3.828535159878358*^9, 3.8285351962518797`*^9, 
   3.8285846491649647`*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"0012f8e5-b78b-4f12-902f-0dd9a57383c1"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SqrtBox["s"], "2"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828534443170586*^9, {3.8285344926713743`*^9, 3.828534500706045*^9}, 
   3.8285349939707336`*^9, 3.828535159878358*^9, 3.8285351962518797`*^9, 
   3.828584649169606*^9},
 CellLabel->"Out[11]=",ExpressionUUID->"21b4e801-5878-4797-a784-da48f051267f"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{
    "Energies", " ", "and", " ", "momenta", " ", "of", " ", "the", " ", 
     "final"}], "-", 
    RowBox[{"state", " ", 
     RowBox[{"particles", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"Solve", "[", 
    RowBox[{
     RowBox[{
      SqrtBox["s"], "\[Equal]", 
      RowBox[{
       SqrtBox[
        SuperscriptBox["p", "2"]], "+", 
       SqrtBox[
        SuperscriptBox["p", "2"]]}]}], ",", "p"}], "]"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"pFinal", "=", 
     FractionBox[
      SqrtBox["s"], "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SqrtBox[
      SuperscriptBox["pFinal", "2"]], "//", "PowerExpand"}], "//", 
    "Simplify"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EFinal", "=", 
     FractionBox[
      SqrtBox["s"], "2"]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8285343991885233`*^9, 3.828534500211405*^9}, {
  3.828534962052822*^9, 3.828534990553317*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"75e3976f-5661-4a82-baef-3d94b400d81b"],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      RowBox[{"-", 
       FractionBox[
        SqrtBox["s"], "2"]}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"p", "\[Rule]", 
      FractionBox[
       SqrtBox["s"], "2"]}], "}"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828534443170586*^9, {3.8285344926713743`*^9, 3.828534500706045*^9}, {
   3.82853497052372*^9, 3.828535000464287*^9}, 3.8285351986238337`*^9, 
   3.8285846492059727`*^9},
 CellLabel->"Out[13]=",ExpressionUUID->"1c1ec2ed-14c3-47da-9000-500da3d1fce8"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SqrtBox["s"], "2"], TraditionalForm]], "Output",
 CellChangeTimes->{
  3.828534443170586*^9, {3.8285344926713743`*^9, 3.828534500706045*^9}, {
   3.82853497052372*^9, 3.828535000464287*^9}, 3.8285351986238337`*^9, 
   3.828584649215849*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"66a42bf8-32c4-439b-a592-4a55080761b7"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Taking the Angles into Account", "Subsection",
 CellChangeTimes->{{3.828534544891247*^9, 
  3.828534556199643*^9}},ExpressionUUID->"a12690fe-30a3-45f8-9297-\
1c62dee9b55b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"RESET", " ", 
    RowBox[{"KERNEL", "!"}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"<<", "FeynCalc`"}]}]], "Input",
 CellLabel->"In[17]:=",ExpressionUUID->"7c4383eb-66ac-42bf-a95a-9d652ca9f1f8"],

Cell[CellGroupData[{

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"FeynCalc \"\>", "Text",
     StripOnInput->False,
     FontWeight->Bold], "\[InvisibleSpace]", 
    StyleBox["\<\"9.3.1 (development version). For help, use the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"documentation", " ", "center"}],
       BaseStyle->"Link",
       ButtonData:>"paclet:FeynCalc/",
       ButtonNote->"paclet:FeynCalc/"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\", check out the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["wiki",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" or visit the \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"forum", "."}],
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None},
       ButtonNote->"http://www.feyncalc.org/forum/"],
      DisplayForm], "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["FeynCalc ", "Text", Bold], 
    Style["9.3.1 (development version). For help, use the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "documentation center", BaseStyle -> "Link", ButtonData :> 
       "paclet:FeynCalc/", ButtonNote -> "paclet:FeynCalc/"]], "Text"], 
    Style[", check out the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["wiki", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki"], None}, BaseStyle -> 
       "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" or visit the ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["forum.", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/discussions"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "http://www.feyncalc.org/forum/"]], "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828534565004195*^9, 3.828584654764347*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"422e56c7-1e78-43d2-b49b-d7f9e192a2d9"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"To save your and our time, please check our \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox["FAQ",
       BaseStyle->"Hyperlink",
       ButtonData:>{
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None},
       ButtonNote->"https://github.com/FeynCalc/feyncalc/wiki"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" for answers to some common FeynCalc questions.\"\>", "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["To save your and our time, please check our ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox["FAQ", ButtonData :> {
         URL["https://github.com/FeynCalc/feyncalc/wiki/FAQ"], None}, 
       BaseStyle -> "Hyperlink", ButtonNote -> 
       "https://github.com/FeynCalc/feyncalc/wiki"]], "Text"], 
    Style[" for answers to some common FeynCalc questions.", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828534565004195*^9, 3.828584654774808*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"99b7d0ab-3d6a-48b0-8fca-5e2298bcb64a"],

Cell[BoxData[
 FormBox[
  InterpretationBox[
   RowBox[{
    StyleBox["\<\"See also the supplied \"\>", "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox[
     TagBox[
      ButtonBox[
       RowBox[{"examples", "."}],
       BaseStyle->"Hyperlink",
       ButtonFunction:>SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]],
       Evaluator->Automatic,
       Method->"Preemptive"],
      DisplayForm], "Text",
     StripOnInput->False], "\[InvisibleSpace]", 
    StyleBox["\<\" If you use FeynCalc in your research, please cite\"\>", 
     "Text",
     StripOnInput->False]}],
   SequenceForm[
    Style["See also the supplied ", "Text"], 
    Style[
     DisplayForm[
      ButtonBox[
      "examples.", BaseStyle -> "Hyperlink", ButtonFunction :> SystemOpen[
         FileNameJoin[{FeynCalc`$FeynCalcDirectory, "Examples"}]], Evaluator -> 
       Automatic, Method -> "Preemptive"]], "Text"], 
    Style[" If you use FeynCalc in your research, please cite", "Text"]],
   Editable->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828534565004195*^9, 3.828584654779256*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"6a6b8c0d-f351-44df-94e1-03d9db896e14"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 256 (2020) 107478, arXiv:2001.04407.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828534565004195*^9, 3.828584654785331*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"a0bee66a-70cb-4627-b040-608a16e323b6"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] V. Shtabovenko, R. Mertig and F. Orellana, \
Comput.Phys.Commun. 207 (2016) 432-444, arXiv:1601.01167.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828534565004195*^9, 3.828584654787641*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"f0278ab6-807b-4f2b-99d7-a7f67b66997d"],

Cell[BoxData[
 FormBox[
  StyleBox["\<\" \[Bullet] R. Mertig, M. B\[ODoubleDot]hm, and A. Denner, \
Comput. Phys. Commun. 64 (1991) 345-359.\"\>", "Text",
   StripOnInput->False], TraditionalForm]], "Print",
 CellChangeTimes->{3.828534565004195*^9, 3.828584654789074*^9},
 CellLabel->
  "During evaluation of \
In[17]:=",ExpressionUUID->"46a3e68d-4b4e-4a61-8306-009358744592"]
}, Open  ]]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "The", " ", "scalar", " ", "products", " ", "needed", " ", "to", " ", 
    "evaluate", " ", "the", " ", "below", " ", 
    RowBox[{"expressions", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "pp", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "pm", "]"}], "=", "0"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "p0", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "q", "]"}], "=", "s"}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", "l", "]"}], "=", 
     SuperscriptBox["M\[Pi]", "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q", ",", "p0"}], "]"}], "=", 
     FractionBox[
      RowBox[{
       SuperscriptBox["MV", "2"], "-", "s", "-", 
       SuperscriptBox["M\[Pi]", "2"]}], "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"q", ",", "l"}], "]"}], "=", 
     FractionBox["s", "2"]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"SP", "[", 
      RowBox[{"l", ",", "p0"}], "]"}], "=", 
     RowBox[{
      RowBox[{"E2Initial", "*", "EIntermediate"}], "-", 
      RowBox[{"pInitial", "*", "pIntermediate", "*", 
       RowBox[{"Cos", "[", 
        RowBox[{"\[Theta]", "'"}], "]"}]}]}]}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.8285345708554373`*^9, 3.8285346219150343`*^9}, {
  3.8285352109812717`*^9, 3.828535211800798*^9}, {3.828535270567733*^9, 
  3.828535379952284*^9}, {3.828535410036374*^9, 3.828535426716085*^9}, {
  3.828536147038287*^9, 3.8285361521874723`*^9}, {3.828539666067862*^9, 
  3.8285396836235*^9}, {3.828539838938857*^9, 3.82853985057195*^9}, {
  3.8285399418483887`*^9, 3.828539949166913*^9}, {3.82854000584589*^9, 
  3.828540021150284*^9}, {3.828540157555131*^9, 3.828540161183444*^9}, {
  3.828540218230712*^9, 3.8285402560304413`*^9}, {3.8285404068387012`*^9, 
  3.8285404074808903`*^9}},
 CellLabel->"In[37]:=",ExpressionUUID->"81210bcd-6b44-41e4-ad89-58e4c08c57e5"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Discontinuity", "Section",
 CellChangeTimes->{{3.8285335738867598`*^9, 3.828533576831871*^9}, 
   3.8285343884001904`*^9},ExpressionUUID->"159fd95a-3971-448d-aad3-\
55183dd10183"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"The", " ", "left"}], "-", 
    RowBox[{
    "hand", " ", "side", " ", "of", " ", "the", " ", "equation", " ", 
     "obtained", " ", "on", " ", "the", " ", "handwritten", " ", 
     RowBox[{"notes", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"LHS", "=", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"LC", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Beta]"}], 
        "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"p0", ",", "\[Nu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q", ",", "\[Alpha]"}], "]"}], 
       RowBox[{"LC", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]2", ",", "\[Alpha]2", ",", "\[Beta]"}], 
        "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"p0", ",", "\[Nu]2"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q", ",", "\[Alpha]2"}], "]"}]}], "]"}], "//", "Simplify"}]}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Check", " ", "that", " ", "the", " ", "above", " ", "is", " ", "equal", 
     " ", "to", " ", "the", " ", "expression", " ", 
     RowBox[{"below", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"LHS", "\[Equal]", 
     FractionBox[
      RowBox[{"\[Lambda]", "[", 
       RowBox[{"s", ",", 
        SuperscriptBox["MV", "2"], ",", 
        SuperscriptBox["M\[Pi]", "2"]}], "]"}], "2"]}], "//", 
    "Reduce"}]}]}]], "Input",
 CellChangeTimes->{{3.8279056112472563`*^9, 3.8279056141090517`*^9}, {
   3.8279057996288433`*^9, 3.827905800025723*^9}, 3.827908754465046*^9, {
   3.828534647353194*^9, 3.828534703843121*^9}, {3.828536191199416*^9, 
   3.828536191795704*^9}, {3.8285398158570223`*^9, 3.8285398179545307`*^9}, {
   3.828540104722106*^9, 3.828540111582427*^9}, {3.8285403168326387`*^9, 
   3.828540317181707*^9}},
 CellLabel->"In[45]:=",ExpressionUUID->"2faa5c0a-f6f5-4932-8554-c454bf696d0f"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "2"], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "-", "s"}], ")"}], "2"], "+", 
     SuperscriptBox["MV", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["MV", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "+", "s"}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.827905458617852*^9, 3.827905803589355*^9, 3.827906076932892*^9, 
   3.827906133309074*^9, 3.827908759019972*^9, 3.828417432448399*^9, 
   3.82853223220393*^9, {3.828534695856587*^9, 3.8285347066028767`*^9}, 
   3.8285361964195843`*^9, 3.828539686135467*^9, {3.828539818745536*^9, 
   3.828539853555287*^9}, 3.8285399510868464`*^9, 3.828540022863289*^9, {
   3.8285401060964622`*^9, 3.828540111971513*^9}, 3.828540319265168*^9, {
   3.828584669436509*^9, 3.82858470128657*^9}},
 CellLabel->"Out[45]=",ExpressionUUID->"1c78a54a-cf1d-4277-8b71-9d108dce014b"],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellChangeTimes->{
  3.827905458617852*^9, 3.827905803589355*^9, 3.827906076932892*^9, 
   3.827906133309074*^9, 3.827908759019972*^9, 3.828417432448399*^9, 
   3.82853223220393*^9, {3.828534695856587*^9, 3.8285347066028767`*^9}, 
   3.8285361964195843`*^9, 3.828539686135467*^9, {3.828539818745536*^9, 
   3.828539853555287*^9}, 3.8285399510868464`*^9, 3.828540022863289*^9, {
   3.8285401060964622`*^9, 3.828540111971513*^9}, 3.828540319265168*^9, {
   3.828584669436509*^9, 3.8285847012918167`*^9}},
 CellLabel->"Out[46]=",ExpressionUUID->"8c9078bc-ce44-48c2-ab08-24c766e88e59"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
    RowBox[{"The", " ", "right"}], "-", 
    RowBox[{
    "hand", " ", "side", " ", "of", " ", "the", " ", "equation", " ", 
     "obtained", " ", "on", " ", "the", " ", "handwritten", " ", 
     RowBox[{"notes", "."}]}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"RHS", "=", 
    RowBox[{
     RowBox[{"Contract", "[", 
      RowBox[{
       RowBox[{"LC", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]", ",", "\[Alpha]", ",", "\[Gamma]"}], 
        "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q", ",", "\[Nu]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"l", ",", "\[Alpha]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"p0", ",", "\[Gamma]"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{
         RowBox[{"q", "-", 
          RowBox[{"2", "l"}]}], ",", "\[Beta]"}], "]"}], 
       RowBox[{"LC", "[", 
        RowBox[{"\[Mu]", ",", "\[Nu]2", ",", "\[Alpha]2", ",", "\[Beta]"}], 
        "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"p0", ",", "\[Nu]2"}], "]"}], 
       RowBox[{"FV", "[", 
        RowBox[{"q", ",", "\[Alpha]2"}], "]"}]}], "]"}], "//", "Simplify"}]}],
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", " ", 
    RowBox[{
    "Check", " ", "that", " ", "the", " ", "above", " ", "is", " ", "equal", 
     " ", "to", " ", "the", " ", "expression", " ", 
     RowBox[{"below", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"RHS", "\[Equal]", 
     RowBox[{
      RowBox[{"-", 
       FractionBox["1", "8"]}], 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"4", 
         SuperscriptBox["M\[Pi]", "2"]}], "-", "s"}], ")"}], 
      SuperscriptBox[
       RowBox[{"Sin", "[", 
        RowBox[{"\[Theta]", "'"}], "]"}], "2"], 
      RowBox[{"\[Lambda]", "[", 
       RowBox[{"s", ",", 
        SuperscriptBox["MV", "2"], ",", 
        SuperscriptBox["M\[Pi]", "2"]}], "]"}]}]}], "//", 
    "Reduce"}]}]}]], "Input",
 CellChangeTimes->{{3.82775020228656*^9, 3.827750249778994*^9}, {
   3.82790531137617*^9, 3.827905320582491*^9}, {3.827905588524118*^9, 
   3.827905608160315*^9}, {3.827905801721098*^9, 3.827905802285475*^9}, 
   3.827908757756338*^9, {3.8285347229201717`*^9, 3.8285347345975037`*^9}, {
   3.828534767847993*^9, 3.8285347683679667`*^9}, {3.828534817432922*^9, 
   3.8285348179657907`*^9}, {3.82853486243676*^9, 3.8285348689377937`*^9}, {
   3.828536193997336*^9, 3.828536194508333*^9}, {3.8285398602470217`*^9, 
   3.828539867116664*^9}, {3.8285401861092978`*^9, 3.828540187959762*^9}, {
   3.82854029167131*^9, 3.82854036939852*^9}, {3.828584739734343*^9, 
   3.828584743273629*^9}},ExpressionUUID->"4859e48d-804d-4f0b-aa25-\
c58e7ef75660"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    FractionBox["1", "8"]}], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"4", " ", 
      SuperscriptBox["M\[Pi]", "2"]}], "-", "s"}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["sin", "2"], "(", 
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], ")"}], " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "-", "s"}], ")"}], "2"], "+", 
     SuperscriptBox["MV", "4"], "-", 
     RowBox[{"2", " ", 
      SuperscriptBox["MV", "2"], " ", 
      RowBox[{"(", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], "+", "s"}], ")"}]}]}], ")"}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.8277502474108*^9, 3.82775025007401*^9}, 
   3.827905145056888*^9, {3.8279051929089108`*^9, 3.827905202436736*^9}, 
   3.827905322637269*^9, 3.8279054613223877`*^9, 3.827905802679241*^9, 
   3.827906078199419*^9, 3.8279061348818893`*^9, 3.827908758127369*^9, 
   3.828417434369915*^9, 3.828532235576544*^9, {3.828534793466131*^9, 
   3.82853481859417*^9}, {3.828534869627211*^9, 3.8285348824001417`*^9}, 
   3.8285354304654913`*^9, 3.8285361545861397`*^9, 3.82853619731207*^9, 
   3.8285396526611967`*^9, 3.828539690493218*^9, 3.8285398688648787`*^9, 
   3.828540117033059*^9, {3.8285401656256113`*^9, 3.8285401887086697`*^9}, 
   3.828540229973629*^9, {3.828540273428871*^9, 3.828540322278778*^9}, {
   3.828540363612286*^9, 3.828540369834147*^9}, {3.8285846714190197`*^9, 
   3.828584702876041*^9}},
 CellLabel->"Out[47]=",ExpressionUUID->"24cc9e44-0dd4-40a7-8943-06987e50186a"],

Cell[BoxData[
 FormBox["True", TraditionalForm]], "Output",
 CellChangeTimes->{{3.8277502474108*^9, 3.82775025007401*^9}, 
   3.827905145056888*^9, {3.8279051929089108`*^9, 3.827905202436736*^9}, 
   3.827905322637269*^9, 3.8279054613223877`*^9, 3.827905802679241*^9, 
   3.827906078199419*^9, 3.8279061348818893`*^9, 3.827908758127369*^9, 
   3.828417434369915*^9, 3.828532235576544*^9, {3.828534793466131*^9, 
   3.82853481859417*^9}, {3.828534869627211*^9, 3.8285348824001417`*^9}, 
   3.8285354304654913`*^9, 3.8285361545861397`*^9, 3.82853619731207*^9, 
   3.8285396526611967`*^9, 3.828539690493218*^9, 3.8285398688648787`*^9, 
   3.828540117033059*^9, {3.8285401656256113`*^9, 3.8285401887086697`*^9}, 
   3.828540229973629*^9, {3.828540273428871*^9, 3.828540322278778*^9}, {
   3.828540363612286*^9, 3.828540369834147*^9}, {3.8285846714190197`*^9, 
   3.828584702880251*^9}},
 CellLabel->"Out[48]=",ExpressionUUID->"4ebba0d5-9c35-4c4b-8b73-4c233be2eb8b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{"The", " ", "ratio", " ", "of", " ", "the", " ", "two", " ", 
    RowBox[{"expressions", "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"RHS", "/", "LHS"}], "//", "FullSimplify"}]}]], "Input",
 CellChangeTimes->{{3.8285361998452997`*^9, 3.828536213070074*^9}, {
  3.8285402947583323`*^9, 3.8285402964087753`*^9}, {3.828540380437594*^9, 
  3.828540387539324*^9}},
 CellLabel->"In[36]:=",ExpressionUUID->"f4defebd-fa44-42b1-ba22-2c1bd385da81"],

Cell[BoxData[
 FormBox[
  RowBox[{
   FractionBox["1", "4"], " ", 
   RowBox[{"(", 
    RowBox[{"s", "-", 
     RowBox[{"4", " ", 
      SuperscriptBox["M\[Pi]", "2"]}]}], ")"}], " ", 
   RowBox[{
    SuperscriptBox["sin", "2"], "(", 
    SuperscriptBox["\[Theta]", "\[Prime]",
     MultilineFunction->None], ")"}]}], TraditionalForm]], "Output",
 CellChangeTimes->{{3.8285362038540087`*^9, 3.828536216066492*^9}, 
   3.828539692641697*^9, 3.8285399167832937`*^9, {3.828540285619169*^9, 
   3.828540299912977*^9}, {3.8285846746741257`*^9, 3.8285846942779007`*^9}},
 CellLabel->"Out[36]=",ExpressionUUID->"c592299f-79af-43d2-9868-a8242f35093e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", " ", 
   RowBox[{
   "Simplify", " ", "the", " ", "obtained", " ", "expression", " ", "in", " ",
     "terms", " ", "of", " ", 
    SubscriptBox["q", "\[Pi]\[Pi]"], 
    RowBox[{
     RowBox[{"(", "s", ")"}], "."}]}], " ", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    FractionBox[
     SqrtBox[
      RowBox[{"\[Lambda]", "[", 
       RowBox[{
        SuperscriptBox["M\[Pi]", "2"], ",", 
        SuperscriptBox["M\[Pi]", "2"], ",", "s"}], "]"}]], 
     RowBox[{"2", 
      SqrtBox["s"]}]], "//", "PowerExpand"}], "//", "Simplify"}]}]], "Input",
 CellChangeTimes->{{3.828541020773806*^9, 3.8285410438337917`*^9}, {
  3.828541286628132*^9, 3.828541287952026*^9}, {3.8285865858970613`*^9, 
  3.828586603466641*^9}},ExpressionUUID->"21631e8b-8229-4242-99b4-\
d48a8e2ac6b9"],

Cell[BoxData[
 FormBox[
  FractionBox[
   SqrtBox[
    RowBox[{"s", " ", 
     RowBox[{"(", 
      RowBox[{"s", "-", 
       RowBox[{"4", " ", 
        SuperscriptBox["M\[Pi]", "2"]}]}], ")"}]}]], 
   RowBox[{"2", " ", 
    SqrtBox["s"]}]], TraditionalForm]], "Output",
 CellChangeTimes->{{3.828541037286222*^9, 3.828541044380307*^9}, 
   3.828541288572117*^9},
 CellLabel->
  "Out[216]=",ExpressionUUID->"f47a197a-e47e-4dcf-9846-25fc05af8c31"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
WindowSize->{808, 602},
WindowMargins->{{-1007, Automatic}, {-118, Automatic}},
FrontEndVersion->"12.0 for Mac OS X x86 (64-bit) (April 8, 2019)",
StyleDefinitions->FrontEnd`FileName[{"Report"}, "StandardReport.nb", 
  CharacterEncoding -> "UTF-8"]
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[580, 22, 474, 14, 98, "Title",ExpressionUUID->"0e5026cd-4cfe-4c5b-a278-e9bc6f147cbe"],
Cell[1057, 38, 712, 20, 84, "Input",ExpressionUUID->"6142dc02-8c6e-475f-895b-be5ca395aa19"],
Cell[CellGroupData[{
Cell[1794, 62, 180, 3, 69, "Section",ExpressionUUID->"71485b68-cf25-4dbd-8ef7-d877f47b1ca1"],
Cell[1977, 67, 927, 26, 128, "Input",ExpressionUUID->"c9bc42c9-dcbb-4dba-9610-23afd3de30b9"],
Cell[CellGroupData[{
Cell[2929, 97, 2292, 71, 352, "Input",ExpressionUUID->"d2085999-7b24-4df7-b8cc-a47083e07d00"],
Cell[5224, 170, 1480, 41, 122, "Output",ExpressionUUID->"aab41839-9eec-409f-a445-aa8f7de0bb79"],
Cell[6707, 213, 517, 15, 74, "Output",ExpressionUUID->"b52e2c04-1130-43ab-b69f-2e0282f8eeeb"],
Cell[7227, 230, 494, 14, 74, "Output",ExpressionUUID->"24e4acf7-a999-471c-8911-eee39d647b22"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7758, 249, 1358, 42, 235, "Input",ExpressionUUID->"0b8e30ee-a80a-4b5c-89d3-f3cab6dd19da"],
Cell[9119, 293, 849, 26, 57, "Output",ExpressionUUID->"0012f8e5-b78b-4f12-902f-0dd9a57383c1"],
Cell[9971, 321, 362, 8, 60, "Output",ExpressionUUID->"21b4e801-5878-4797-a784-da48f051267f"]
}, Open  ]],
Cell[CellGroupData[{
Cell[10370, 334, 1156, 36, 235, "Input",ExpressionUUID->"75e3976f-5661-4a82-baef-3d94b400d81b"],
Cell[11529, 372, 598, 17, 60, "Output",ExpressionUUID->"1c1ec2ed-14c3-47da-9000-500da3d1fce8"],
Cell[12130, 391, 361, 8, 60, "Output",ExpressionUUID->"66a42bf8-32c4-439b-a592-4a55080761b7"]
}, Open  ]],
Cell[CellGroupData[{
Cell[12528, 404, 178, 3, 34, "Subsection",ExpressionUUID->"a12690fe-30a3-45f8-9297-1c62dee9b55b"],
Cell[CellGroupData[{
Cell[12731, 411, 261, 6, 63, "Input",ExpressionUUID->"7c4383eb-66ac-42bf-a95a-9d652ca9f1f8"],
Cell[CellGroupData[{
Cell[13017, 421, 2492, 67, 49, "Print",ExpressionUUID->"422e56c7-1e78-43d2-b49b-d7f9e192a2d9"],
Cell[15512, 490, 1230, 30, 30, "Print",ExpressionUUID->"99b7d0ab-3d6a-48b0-8fca-5e2298bcb64a"],
Cell[16745, 522, 1236, 33, 30, "Print",ExpressionUUID->"6a6b8c0d-f351-44df-94e1-03d9db896e14"],
Cell[17984, 557, 388, 8, 27, "Print",ExpressionUUID->"a0bee66a-70cb-4627-b040-608a16e323b6"],
Cell[18375, 567, 389, 8, 27, "Print",ExpressionUUID->"f0278ab6-807b-4f2b-99d7-a7f67b66997d"],
Cell[18767, 577, 376, 8, 27, "Print",ExpressionUUID->"46a3e68d-4b4e-4a61-8306-009358744592"]
}, Open  ]]
}, Open  ]],
Cell[19170, 589, 2401, 61, 352, "Input",ExpressionUUID->"81210bcd-6b44-41e4-ad89-58e4c08c57e5"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[21620, 656, 185, 3, 69, "Section",ExpressionUUID->"159fd95a-3971-448d-aad3-55183dd10183"],
Cell[CellGroupData[{
Cell[21830, 663, 1993, 48, 190, "Input",ExpressionUUID->"2faa5c0a-f6f5-4932-8554-c454bf696d0f"],
Cell[23826, 713, 1043, 25, 57, "Output",ExpressionUUID->"1c78a54a-cf1d-4277-8b71-9d108dce014b"],
Cell[24872, 740, 642, 10, 37, "Output",ExpressionUUID->"8c9078bc-ce44-48c2-ab08-24c766e88e59"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25551, 755, 2731, 67, 185, "Input",ExpressionUUID->"4859e48d-804d-4f0b-aa25-c58e7ef75660"],
Cell[28285, 824, 1640, 38, 57, "Output",ExpressionUUID->"24cc9e44-0dd4-40a7-8943-06987e50186a"],
Cell[29928, 864, 961, 14, 37, "Output",ExpressionUUID->"4ebba0d5-9c35-4c4b-8b73-4c233be2eb8b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[30926, 883, 519, 10, 63, "Input",ExpressionUUID->"f4defebd-fa44-42b1-ba22-2c1bd385da81"],
Cell[31448, 895, 643, 15, 57, "Output",ExpressionUUID->"c592299f-79af-43d2-9868-a8242f35093e"]
}, Open  ]],
Cell[CellGroupData[{
Cell[32128, 915, 824, 22, 97, "Input",ExpressionUUID->"21631e8b-8229-4242-99b4-d48a8e2ac6b9"],
Cell[32955, 939, 444, 14, 84, "Output",ExpressionUUID->"f47a197a-e47e-4dcf-9846-25fc05af8c31"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

